@@ -17,7 +17,9 @@
 #' @export
 apply_mapshaper_commands <- function(data, command, force_FC, sys = FALSE) {
 
-  if (file.exists(data) & !sys) {
+  data <- as.character(data)
+
+  if (nchar(data) < 1000L && file.exists(data) && !sys) {
     stop("'data' points to a file on disk but you did not specify to use
          the system mapshaper. To do so set sys = TRUE")
   }
@@ -43,8 +45,17 @@ apply_mapshaper_commands <- function(data, command, force_FC, sys = FALSE) {
     ## Create a JS object to hold the returned data
     ms$eval("var return_data;")
 
-    ms$call("mapshaper.applyCommands", command, as.character(data),
+    ms$call("mapshaper.applyCommands", command, data,
             V8::JS(callback()))
+
+    # TODO: New syntax for applyCommands:
+    # Useful for clip and erase so can define two inputs
+    # cmd <- paste("-i input.geojson", command, "-o output.geojson")
+    #
+    # ms$call("mapshaper.applyCommands", cmd, V8::JS("{'input.geojson': input}"),
+    #         V8::JS("function(err, output) {
+    # 	return_data = output['output.geojson'];
+    # }"))
     ret <- ms$get("return_data")
     ret <- class_geo_json(ret)
   }
@@ -191,7 +202,10 @@ ms_sf <- function(input, call, sys = FALSE) {
     names(ret)[names(ret) == attr(ret, "sf_column")] <- geom_name
     sf::st_geometry(ret) <- geom_name
   }
-
+  ##maintain tbl_df
+  if (all(class(input) == c("sf", "tbl_df", "tbl", "data.frame"))) {
+    class(ret) <- c("sf", "tbl_df", "tbl", "data.frame")
+  }
   ret
 }
 
@@ -220,8 +234,8 @@ sf_to_GeoJSON <- function(sf, file = FALSE){
 geo_list_to_json <- function(x) {
   suppressMessages(
     jsonlite::toJSON(unclass(
-      geojsonio::geojson_list(x, type = 'auto')
-    ), auto_unbox = TRUE, digits = 7)
+      geojsonio::geojson_list(x, type = "auto")
+    ), auto_unbox = TRUE, digits = 7, na = "null")
   )
 }
 
