@@ -70,7 +70,7 @@ test_that("ms_clip.geo_json works", {
   default_clip_json <- ms_clip(poly, clip_poly)
 
   expect_is(default_clip_json, "geo_json")
-  # expect_equal(default_clip_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[52.8658,-44.7219],[53.7702,-40.4873],[54.02807275892674,-40],[55,-40],[55,-45],[51,-45],[51,-42.353820249760446],[52.8658,-44.7219]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
+  # expect_equivalent(default_clip_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[52.8658,-44.7219],[53.7702,-40.4873],[54.02807275892674,-40],[55,-40],[55,-45],[51,-45],[51,-42.353820249760446],[52.8658,-44.7219]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
   expect_true(geojsonlint::geojson_validate(default_clip_json))
 
   skip_if_not(has_sys_mapshaper())
@@ -81,7 +81,7 @@ test_that("ms_clip.character works", {
   default_clip_json <- ms_clip(unclass(poly), unclass(clip_poly))
 
   expect_is(default_clip_json, "geo_json")
-  #expect_equal(default_clip_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[52.8658,-44.7219],[53.7702,-40.4873],[54.02807275892674,-40],[55,-40],[55,-45],[51,-45],[51,-42.353820249760446],[52.8658,-44.7219]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
+  #expect_equivalent(default_clip_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[52.8658,-44.7219],[53.7702,-40.4873],[54.02807275892674,-40],[55,-40],[55,-45],[51,-45],[51,-42.353820249760446],[52.8658,-44.7219]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
   expect_true(geojsonlint::geojson_validate(default_clip_json))
 })
 
@@ -89,7 +89,7 @@ test_that("ms_erase.geo_json works", {
   default_erase_json <- ms_erase(poly, clip_poly)
 
   expect_is(default_erase_json, "geo_json")
-  #expect_equal(default_erase_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[54.02807275892674,-40],[55.3204,-37.5579],[56.2757,-37.917],[56.184,-40.6443],[61.0835,-40.7529],[58.0202,-43.634],[61.6699,-45.0678],[62.737,-46.2841],[55.7763,-46.2637],[54.9742,-49.1184],[52.799,-45.9386],[52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],[52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],[50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],[51,-42.353820249760446],[51,-45],[55,-45],[55,-40],[54.02807275892674,-40]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
+  #expect_equivalent(default_erase_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[54.02807275892674,-40],[55.3204,-37.5579],[56.2757,-37.917],[56.184,-40.6443],[61.0835,-40.7529],[58.0202,-43.634],[61.6699,-45.0678],[62.737,-46.2841],[55.7763,-46.2637],[54.9742,-49.1184],[52.799,-45.9386],[52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],[52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],[50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],[51,-42.353820249760446],[51,-45],[55,-45],[55,-40],[54.02807275892674,-40]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
   expect_true(geojsonlint::geojson_validate(default_erase_json))
 
   skip_if_not(has_sys_mapshaper())
@@ -100,7 +100,7 @@ test_that("ms_erase.character works", {
   default_erase_json <- ms_erase(unclass(poly), unclass(clip_poly))
 
   expect_is(default_erase_json, "geo_json")
-  #expect_equal(default_erase_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[54.02807275892674,-40],[55.3204,-37.5579],[56.2757,-37.917],[56.184,-40.6443],[61.0835,-40.7529],[58.0202,-43.634],[61.6699,-45.0678],[62.737,-46.2841],[55.7763,-46.2637],[54.9742,-49.1184],[52.799,-45.9386],[52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],[52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],[50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],[51,-42.353820249760446],[51,-45],[55,-45],[55,-40],[54.02807275892674,-40]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
+  #expect_equivalent(default_erase_json, structure("{\"type\":\"FeatureCollection\",\"features\":[\n{\"type\":\"Feature\",\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[54.02807275892674,-40],[55.3204,-37.5579],[56.2757,-37.917],[56.184,-40.6443],[61.0835,-40.7529],[58.0202,-43.634],[61.6699,-45.0678],[62.737,-46.2841],[55.7763,-46.2637],[54.9742,-49.1184],[52.799,-45.9386],[52.0329,-49.5677],[50.1747,-52.1814],[49.0098,-52.3641],[52.7068,-45.7639],[43.2278,-47.1908],[48.4755,-45.1388],[50.327,-43.5207],[48.0804,-41.2784],[49.6307,-40.6159],[51,-42.353820249760446],[51,-45],[55,-45],[55,-40],[54.02807275892674,-40]]]},\"properties\":{\"rmapshaperid\":0}}\n]}", class = c("json", "geo_json")))
   expect_true(geojsonlint::geojson_validate(default_erase_json))
 })
 
@@ -109,11 +109,11 @@ test_that("ms_clip.SpatialPolygons works", {
   default_clip_spdf <- ms_clip(poly_spdf, clip_poly_spdf)
 
   expect_is(default_clip_spdf, "SpatialPolygonsDataFrame")
-  expect_equal(sapply(default_clip_spdf@polygons[[1]]@Polygons, function(x) length(x@coords)), 10)
+  expect_equivalent(sapply(default_clip_spdf@polygons[[1]]@Polygons, function(x) length(x@coords)), 10)
   expect_true(rgeos::gIsValid(default_clip_spdf))
 
   default_clip_sp <- ms_clip(poly_sp, clip_poly_spdf)
-  expect_equal(as(default_clip_spdf, "SpatialPolygons"), default_clip_sp)
+  expect_equivalent(as(default_clip_spdf, "SpatialPolygons"), default_clip_sp)
 
   skip_if_not(has_sys_mapshaper())
   expect_is(ms_clip(poly_spdf, clip_poly_spdf, sys = TRUE), "SpatialPolygonsDataFrame")
@@ -123,11 +123,11 @@ test_that("ms_erase.SpatialPolygons works", {
   default_erase_spdf <- ms_erase(poly_spdf, clip_poly_spdf)
 
   expect_is(default_erase_spdf, "SpatialPolygonsDataFrame")
-  expect_equal(sapply(default_erase_spdf@polygons[[1]]@Polygons, function(x) length(x@coords)), 14)
+  expect_equivalent(sapply(default_erase_spdf@polygons[[1]]@Polygons, function(x) length(x@coords)), 14)
   expect_true(rgeos::gIsValid(default_erase_spdf))
 
   default_erase_sp <- ms_erase(poly_sp, clip_poly_spdf)
-  expect_equal(as(default_erase_spdf, "SpatialPolygons"), default_erase_sp)
+  expect_equivalent(as(default_erase_spdf, "SpatialPolygons"), default_erase_sp)
 
   skip_if_not(has_sys_mapshaper())
   expect_is(ms_erase(poly_spdf, clip_poly_spdf, sys = TRUE), "SpatialPolygonsDataFrame")
@@ -144,14 +144,14 @@ test_that("ms_clip works with lines", {
 {"type":"Feature","geometry":{"type":"LineString","coordinates":[[55,-40.125],[52,-42]]},"properties":{"rmapshaperid":0}}
 ]}', class = c("json","geo_json"))
 
-  expect_equal(clean_ws(ms_clip(line, clip_poly)), clean_ws(expected_out))
-  expect_equal(ms_clip(line_list, geojson_list(clip_poly)), geojson_list(expected_out))
-  expect_equal(ms_clip(line_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
-  expect_equal(ms_clip(line_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialLines"))
-  expect_equal(clean_ws(ms_clip(line, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
-  expect_equal(ms_clip(line_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
-  expect_equal(ms_clip(line_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
-  expect_equal(ms_clip(line_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialLines"))
+  expect_equivalent(clean_ws(ms_clip(line, clip_poly)), clean_ws(expected_out))
+  expect_equivalent(ms_clip(line_list, geojson_list(clip_poly)), geojson_list(expected_out))
+  expect_equivalent(ms_clip(line_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
+  expect_equivalent(ms_clip(line_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialLines"))
+  expect_equivalent(clean_ws(ms_clip(line, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
+  expect_equivalent(ms_clip(line_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
+  expect_equivalent(ms_clip(line_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
+  expect_equivalent(ms_clip(line_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialLines"))
 })
 
 test_that("ms_erase works with lines", {
@@ -159,53 +159,53 @@ test_that("ms_erase works with lines", {
 {"type":"Feature","geometry":{"type":"LineString","coordinates":[[60,-37],[55,-40.125]]},"properties":{"rmapshaperid":0}}
 ]} ', class = c("json", "geo_json"))
 
-  expect_equal(clean_ws(ms_erase(line, clip_poly)), clean_ws(expected_out))
-  expect_equal(ms_erase(line_list, geojson_list(clip_poly)), geojson_list(expected_out))
-  expect_equal(ms_erase(line_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
-  expect_equal(ms_erase(line_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialLines"))
-  expect_equal(clean_ws(ms_erase(line, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
-  expect_equal(ms_erase(line_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
-  expect_equal(ms_erase(line_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
-  expect_equal(ms_erase(line_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialLines"))
+  expect_equivalent(clean_ws(ms_erase(line, clip_poly)), clean_ws(expected_out))
+  expect_equivalent(ms_erase(line_list, geojson_list(clip_poly)), geojson_list(expected_out))
+  expect_equivalent(ms_erase(line_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
+  expect_equivalent(ms_erase(line_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialLines"))
+  expect_equivalent(clean_ws(ms_erase(line, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
+  expect_equivalent(ms_erase(line_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
+  expect_equivalent(ms_erase(line_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
+  expect_equivalent(ms_erase(line_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialLines"))
 })
 
 test_that("ms_clip works with points", {
   expected_out <- structure('{"type":"FeatureCollection", "features": [
 {"type":"Feature","geometry":{"type":"Point","coordinates":[53,-42]},"properties":{"rmapshaperid":0}}
 ]}', class = c("json", "geo_json"))
-  expect_equal(clean_ws(ms_clip(points, clip_poly)), clean_ws(expected_out))
-  expect_equal(ms_clip(points_list, geojson_list(clip_poly)), geojson_list(expected_out))
-  expect_equal(ms_clip(points_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
-  expect_equal(ms_clip(points_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialPoints"))
-  expect_equal(clean_ws(ms_clip(points, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
-  expect_equal(ms_clip(points_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
-  expect_equal(ms_clip(points_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
-  expect_equal(ms_clip(points_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialPoints"))
+  expect_equivalent(clean_ws(ms_clip(points, clip_poly)), clean_ws(expected_out))
+  expect_equivalent(ms_clip(points_list, geojson_list(clip_poly)), geojson_list(expected_out))
+  expect_equivalent(ms_clip(points_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
+  expect_equivalent(ms_clip(points_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialPoints"))
+  expect_equivalent(clean_ws(ms_clip(points, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
+  expect_equivalent(ms_clip(points_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
+  expect_equivalent(ms_clip(points_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
+  expect_equivalent(ms_clip(points_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialPoints"))
 })
 
 test_that("ms_erase works with points", {
   expected_out <- structure('{"type":"FeatureCollection", "features": [
 {"type":"Feature","geometry":{"type":"Point","coordinates":[57,-42]},"properties":{"rmapshaperid":0}}
 ]}', class = c("json", "geo_json"))
-  expect_equal(clean_ws(ms_erase(points, clip_poly)), clean_ws(expected_out))
-  expect_equal(ms_erase(points_list, geojson_list(clip_poly)), geojson_list(expected_out))
-  expect_equal(ms_erase(points_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
-  expect_equal(ms_erase(points_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialPoints"))
-  expect_equal(clean_ws(ms_erase(points, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
-  expect_equal(ms_erase(points_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
-  expect_equal(ms_erase(points_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
-  expect_equal(ms_erase(points_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialPoints"))
+  expect_equivalent(clean_ws(ms_erase(points, clip_poly)), clean_ws(expected_out))
+  expect_equivalent(ms_erase(points_list, geojson_list(clip_poly)), geojson_list(expected_out))
+  expect_equivalent(ms_erase(points_spdf, geojson_sp(clip_poly)), geojson_sp(expected_out))
+  expect_equivalent(ms_erase(points_sp, geojson_sp(clip_poly)), as(geojson_sp(expected_out), "SpatialPoints"))
+  expect_equivalent(clean_ws(ms_erase(points, bbox = c(51, -45, 55, -40))), clean_ws(expected_out))
+  expect_equivalent(ms_erase(points_list, bbox = c(51, -45, 55, -40)), geojson_list(expected_out))
+  expect_equivalent(ms_erase(points_spdf, bbox = c(51, -45, 55, -40)), geojson_sp(expected_out))
+  expect_equivalent(ms_erase(points_sp, bbox = c(51, -45, 55, -40)), as(geojson_sp(expected_out), "SpatialPoints"))
 })
 
 test_that("bbox works", {
   out <- ms_erase(poly, bbox = c(51, -45, 55, -40))
   expect_is(out, "geo_json")
-  expect_equal(clean_ws(out), clean_ws(structure('{"type":"FeatureCollection", "features": [
+  expect_equivalent(clean_ws(out), clean_ws(structure('{"type":"FeatureCollection", "features": [
 {"type":"Feature","geometry":{"type":"Polygon","coordinates":[[[55,-42],[57,-42],[57,-47],[53,-47],[53,-45],[55,-45],[55,-42]]]},"properties":{"rmapshaperid":0}}
 ]}', class = c("json", "geo_json"))))
   out <- ms_clip(poly, bbox = c(51, -45, 55, -40))
   expect_is(out, "geo_json")
-  expect_equal(clean_ws(out), clean_ws(structure('{"type":"FeatureCollection", "features": [
+  expect_equivalent(clean_ws(out), clean_ws(structure('{"type":"FeatureCollection", "features": [
 {"type":"Feature","geometry":{"type":"Polygon","coordinates":[[[53,-42],[55,-42],[55,-45],[53,-45],[53,-42]]]},"properties":{"rmapshaperid":0}}
 ]}', class = c("json", "geo_json"))))
 
@@ -230,7 +230,7 @@ clip_sf <- read_sf(unclass(clip_poly))
 
 test_that("clip works with sf objects", {
   expect_is(ms_clip(poly_sf, clip_sf), "sf")
-  expect_equal(names(ms_clip(poly_sf, clip_sf)), c("rmapshaperid", "geometry"))
+  expect_equivalent(names(ms_clip(poly_sf, clip_sf)), c("rmapshaperid", "geometry"))
   expect_is(ms_clip(poly_sfc, clip_sf), "sfc")
   expect_is(ms_clip(lines_sf, clip_sf), "sf")
   expect_is(ms_clip(points_sf, clip_sf), "sf")
@@ -242,7 +242,7 @@ test_that("clip works with sf objects", {
 
 test_that("erase works with sf objects", {
   expect_is(ms_erase(poly_sf, clip_sf), "sf")
-  expect_equal(names(ms_erase(poly_sf, clip_sf)), c("rmapshaperid", "geometry"))
+  expect_equivalent(names(ms_erase(poly_sf, clip_sf)), c("rmapshaperid", "geometry"))
   expect_is(ms_erase(poly_sfc, clip_sf), "sfc")
   expect_is(ms_erase(lines_sf, clip_sf), "sf")
   expect_is(ms_erase(points_sf, clip_sf), "sf")
